@@ -89,9 +89,9 @@ impl Client {
     pub(crate) async fn read_from_network(&self, name: &XorName) -> Result<Chunk> {
         trace!("Fetching chunk: {:?}", name);
 
-        let address = ChunkAddress(*name);
-
-        let res = self.send_query(DataQuery::GetChunk(address)).await?;
+        let res = self
+            .send_query(DataQuery::GetChunk(ChunkAddress(*name)))
+            .await?;
 
         let operation_id = res.operation_id;
         let chunk: Chunk = match res.response {
@@ -265,7 +265,7 @@ impl Client {
 #[cfg(test)]
 mod tests {
     use crate::client::client_api::blob_apis::Blob;
-    use crate::client::utils::test_utils::{create_test_client, run_w_backoff_delayed};
+    use crate::client::utils::test_utils::create_test_client;
     use crate::types::{utils::random_bytes, Keypair};
     use crate::url::Scope;
     use bytes::Bytes;
@@ -316,11 +316,14 @@ mod tests {
             .await?;
 
         // the larger the file, the longer we have to wait before we start querying
-        let delay = usize::max(1, blob.bytes().len() / DELAY_DIVIDER);
+        let delay = tokio::time::Duration::from_secs(usize::max(
+            1,
+            blob.bytes().len() / DELAY_DIVIDER,
+        ) as u64);
+        tokio::time::sleep(delay).await;
 
         // Assert that the blob is stored.
-        let read_data =
-            run_w_backoff_delayed(|| client.read_blob(private_address), 10, delay).await?;
+        let read_data = client.read_blob(private_address).await?;
 
         compare(blob.bytes(), read_data)?;
 
@@ -337,8 +340,7 @@ mod tests {
             .await?;
 
         // Assert that the public blob is stored.
-        let read_data =
-            run_w_backoff_delayed(|| client.read_blob(public_address), 10, delay).await?;
+        let read_data = client.read_blob(public_address).await?;
 
         compare(blob.bytes(), read_data)?;
 
@@ -463,10 +465,11 @@ mod tests {
         let address = client.write_blob_to_network(blob.clone(), scope).await?;
 
         // the larger the file, the longer we have to wait before we start querying
-        let delay = usize::max(1, size / DELAY_DIVIDER);
+        let delay = tokio::time::Duration::from_secs(usize::max(1, size / DELAY_DIVIDER) as u64);
+        tokio::time::sleep(delay).await;
 
         // now that it was written to the network we should be able to retrieve it
-        let read_data = run_w_backoff_delayed(|| client.read_blob(address), 10, delay).await?;
+        let read_data = client.read_blob(address).await?;
         // then the content should be what we stored
         compare(blob.bytes(), read_data)?;
 
@@ -479,10 +482,12 @@ mod tests {
         let address = client.write_spot_to_network(spot.clone(), scope).await?;
 
         // the larger the size, the longer we have to wait before we start querying
-        let delay = usize::max(1, size / DELAY_DIVIDER);
+        let delay = tokio::time::Duration::from_secs(usize::max(1, size / DELAY_DIVIDER) as u64);
+        tokio::time::sleep(delay).await;
 
         // now that it was written to the network we should be able to retrieve it
-        let read_data = run_w_backoff_delayed(|| client.read_spot(address), 10, delay).await?;
+        let read_data = client.read_spot(address).await?;
+
         // then the content should be what we stored
         compare(spot.bytes(), read_data)?;
 
@@ -496,10 +501,10 @@ mod tests {
             .await?;
 
         // the larger the file, the longer we have to wait before we start querying
-        let delay = usize::max(1, len / DELAY_DIVIDER);
+        let delay = tokio::time::Duration::from_secs(usize::max(1, len / DELAY_DIVIDER) as u64);
+        tokio::time::sleep(delay).await;
 
-        let read_data =
-            run_w_backoff_delayed(|| client.read_blob_from(address, pos, len), 10, delay).await?;
+        let read_data = client.read_blob_from(address, pos, len).await?;
 
         compare(blob.bytes().slice(pos..(pos + len)), read_data.clone())?;
 
