@@ -270,7 +270,11 @@ mod tests {
 
             // write to the register
             let _value1_hash = run_w_backoff_delayed(
-                || client.write_to_register(address, value_1.clone(), BTreeSet::new()),
+                || async {
+                    Ok(client
+                        .write_to_register(address, value_1.clone(), BTreeSet::new())
+                        .await?)
+                },
                 10,
                 1,
             )
@@ -303,7 +307,10 @@ mod tests {
             .store_private_register(name, tag, owner, perms)
             .await?;
 
-        let register = run_w_backoff_delayed(|| client.get_register(address), 10, 1).await?;
+        let delay = tokio::time::Duration::from_secs(1);
+        tokio::time::sleep(delay).await;
+
+        let register = client.get_register(address).await?;
 
         assert!(register.is_private());
         assert_eq!(*register.name(), name);
@@ -318,7 +325,8 @@ mod tests {
             .store_public_register(name, tag, owner, perms)
             .await?;
 
-        let register = run_w_backoff_delayed(|| client.get_register(address), 10, 1).await?;
+        tokio::time::sleep(delay).await;
+        let register = client.get_register(address).await?;
 
         assert!(register.is_public());
         assert_eq!(*register.name(), name);
@@ -341,16 +349,17 @@ mod tests {
             .store_private_register(name, tag, owner, perms)
             .await?;
 
-        let register = run_w_backoff_delayed(|| client.get_register(address), 10, 1).await?;
+        let delay = tokio::time::Duration::from_secs(1);
+        tokio::time::sleep(delay).await;
+
+        let register = client.get_register(address).await?;
 
         assert_eq!(register.size(None)?, 0);
 
-        let permissions = run_w_backoff_delayed(
-            || client.get_register_permissions_for_user(address, owner),
-            10,
-            1,
-        )
-        .await?;
+        tokio::time::sleep(delay).await;
+        let permissions = client
+            .get_register_permissions_for_user(address, owner)
+            .await?;
 
         match permissions {
             Permissions::Private(user_perms) => {
@@ -384,12 +393,12 @@ mod tests {
             .store_public_register(name, tag, owner, perms)
             .await?;
 
-        let permissions = run_w_backoff_delayed(
-            || client.get_register_permissions_for_user(address, owner),
-            10,
-            1,
-        )
-        .await?;
+        let delay = tokio::time::Duration::from_secs(1);
+        tokio::time::sleep(delay).await;
+
+        let permissions = client
+            .get_register_permissions_for_user(address, owner)
+            .await?;
 
         match permissions {
             Permissions::Public(user_perms) => {
@@ -430,7 +439,11 @@ mod tests {
 
         // write to the register
         let value1_hash = run_w_backoff_delayed(
-            || client.write_to_register(address, value_1.clone(), BTreeSet::new()),
+            || async {
+                Ok(client
+                    .write_to_register(address, value_1.clone(), BTreeSet::new())
+                    .await?)
+            },
             10,
             1,
         )
@@ -447,7 +460,11 @@ mod tests {
 
         // write to the register
         let value2_hash = run_w_backoff_delayed(
-            || client.write_to_register(address, value_2.clone(), BTreeSet::new()),
+            || async {
+                Ok(client
+                    .write_to_register(address, value_2.clone(), BTreeSet::new())
+                    .await?)
+            },
             10,
             1,
         )
@@ -460,15 +477,14 @@ mod tests {
 
         assert_eq!(2, hashes.len());
 
+        let delay = tokio::time::Duration::from_secs(1);
+        tokio::time::sleep(delay).await;
         // get_register_entry
-        let retrieved_value_1 =
-            run_w_backoff_delayed(|| client.get_register_entry(address, value1_hash), 10, 1)
-                .await?;
+        let retrieved_value_1 = client.get_register_entry(address, value1_hash).await?;
         assert_eq!(retrieved_value_1, value_1);
 
-        let retrieved_value_2 =
-            run_w_backoff_delayed(|| client.get_register_entry(address, value2_hash), 10, 1)
-                .await?;
+        tokio::time::sleep(delay).await;
+        let retrieved_value_2 = client.get_register_entry(address, value2_hash).await?;
         assert_eq!(retrieved_value_2, value_2);
 
         // Requesting a hash which desn't exist throws an error
@@ -497,8 +513,7 @@ mod tests {
             .await?;
 
         // Assert that the data is stored.
-        let current_owner =
-            run_w_backoff_delayed(|| client.get_register_owner(address), 10, 1).await?;
+        let current_owner = client.get_register_owner(address).await?;
 
         assert_eq!(owner, current_owner);
 
@@ -519,7 +534,10 @@ mod tests {
             .store_private_register(name, tag, owner, perms)
             .await?;
 
-        let register = run_w_backoff_delayed(|| client.get_register(address), 10, 1).await?;
+        let delay = tokio::time::Duration::from_secs(1);
+        tokio::time::sleep(delay).await;
+
+        let register = client.get_register(address).await?;
 
         assert!(register.is_private());
 
@@ -557,7 +575,10 @@ mod tests {
             .store_public_register(name, tag, owner, perms)
             .await?;
 
-        let register = run_w_backoff_delayed(|| client.get_register(address), 10, 1).await?;
+        let delay = tokio::time::Duration::from_secs(1);
+        tokio::time::sleep(delay).await;
+
+        let register = client.get_register(address).await?;
         assert!(register.is_public());
 
         match client.delete_register(address).await {
